@@ -12,7 +12,6 @@
 #' viability <- c("108.67","111","102.16","100.27","90","87","74","57")
 #' computeAUC(dose, viability)
 #'
-#'
 #' @param conc [vector] is a vector of drug concentrations.
 #' @param viability [vector] is a vector whose entries are the viability values observed in the presence of the
 #' drug concentrations whose logarithms are in the corresponding entries of the log_conc, where viability 0
@@ -46,7 +45,6 @@
 #' @return A vector containing estimates for HS, E_inf, and EC50
 #' @export
 #' @importFrom stats optim dcauchy dnorm pcauchy rcauchy rnorm pnorm integrate
-
 logLogisticRegression <- function(conc,
                                   viability,
                                   density = c(2, 10, 2),
@@ -61,56 +59,41 @@ logLogisticRegression <- function(conc,
                                   viability_as_pct = TRUE,
                                   trunc = TRUE,
                                   verbose = FALSE) {
-  # guess <- .logLogisticRegressionRaw(conc, viability, density , step, precision, lower_bounds, upper_bounds, scale, Cauchy_flag, conc_as_log, viability_as_pct, trunc, verbose)
 
-
-  # .logLogisticRegressionRaw <- function(conc,
-  #                                   viability,
-  #                                   density = c(2, 10, 2),
-  #                                   step = .5 / density,
-  #                                   precision = 0.05,
-  #                                   lower_bounds = c(0, 0, -6),
-  #                                   upper_bounds = c(4, 1, 6),
-  #                                   scale = 0.07,
-  #                                   Cauchy_flag = FALSE,
-  #                                   conc_as_log = FALSE,
-  #                                   viability_as_pct = TRUE,
-  #                                   trunc = TRUE,
-  #                                   verbose = FALSE) {
   family <- match.arg(family)
 
   if (prod(is.finite(step)) != 1) {
-    print(step)
+    message(step)
     stop("Step vector contains elements which are not positive real numbers.")
   }
 
   if (prod(is.finite(precision)) != 1) {
-    print(precision)
+    message(precision)
     stop("Precision value is not a real number.")
   }
 
   if (prod(is.finite(lower_bounds)) != 1) {
-    print(lower_bounds)
+    message(lower_bounds)
     stop("Lower bounds vector contains elements which are not real numbers.")
   }
 
   if (prod(is.finite(upper_bounds)) != 1) {
-    print(upper_bounds)
+    message(upper_bounds)
     stop("Upper bounds vector contains elements which are not real numbers.")
   }
 
   if (prod(is.finite(density)) != 1) {
-    print(density)
+    message(density)
     stop("Density vector contains elements which are not real numbers.")
   }
 
   if (is.finite(scale) == FALSE) {
-    print(scale)
+    message(scale)
     stop("Scale is not a real number.")
   }
 
   if (is.character(family) == FALSE) {
-    print(family)
+    message(family)
     stop("Cauchy flag is not a string.")
   }
 
@@ -124,29 +107,29 @@ logLogisticRegression <- function(conc,
 
 
   if (min(upper_bounds - lower_bounds) < 0) {
-    print(rbind(lower_bounds, upper_bounds))
+    message(rbind(lower_bounds, upper_bounds))
     stop("Upper bounds on parameters do not exceed lower bounds.")
   }
 
 
 
   if (min(density) <= 0) {
-    print(density)
+    message(density)
     stop("Lattice point density vector contains negative values.")
   }
 
   if (precision <= 0) {
-    print(precision)
+    message(precision)
     stop("Negative precision value.")
   }
 
   if (min(step) <= 0) {
-    print(step)
+    message(step)
     stop("Step vector contains nonpositive numbers.")
   }
 
   if (scale <= 0) {
-    print(scale)
+    message(scale)
     stop("Scale parameter is a nonpositive number.")
   }
 
@@ -162,7 +145,6 @@ logLogisticRegression <- function(conc,
 
 
   #ATTEMPT TO REFINE GUESS WITH L-BFGS OPTIMIZATION
-  # tryCatch(
   gritty_guess <- c(pmin(pmax(1, lower_bounds[1]), upper_bounds[1]),
                     pmin(pmax(min(viability), lower_bounds[2]), upper_bounds[2]),
                     pmin(pmax(log_conc[which.min(abs(viability - 1/2))], lower_bounds[3]), upper_bounds[3]))
@@ -178,13 +160,11 @@ logLogisticRegression <- function(conc,
                           lower = lower_bounds,
                           upper = upper_bounds,
                           method = "L-BFGS-B",
-                          #control=list(maxit=100000)
-  ),#[[1]],
+  ),
   error = function(e) {
     list("par"=gritty_guess, "convergence"=-1)
   })
-  # if(guess[["convergence"]]!=0)  print(guess[["message"]]); #print(results[["convergence"]])
-  failed = guess[["convergence"]]!=0
+  failed = guess[["convergence"]] != 0
   guess <- guess[["par"]]
 
   guess_residual <- .residual(log_conc,
@@ -197,7 +177,6 @@ logLogisticRegression <- function(conc,
 
 
   #GENERATE INITIAL GUESS BY OBJECTIVE FUNCTION EVALUATION AT LATTICE POINTS
-
   gritty_guess_residual <- .residual(log_conc,
                                      viability,
                                      pars = gritty_guess,
@@ -242,7 +221,7 @@ logLogisticRegression <- function(conc,
       neighbours[5, 3] <- pmin(neighbours[5, 3] + span * step[3], upper_bounds[3])
       neighbours[6, 3] <- pmax(neighbours[6, 3] - span * step[3], lower_bounds[3])
 
-      for (i in 1:nrow(neighbours)) {
+      for (i in seq_len(nrow(neighbours))) {
         neighbour_residuals[i] <- .residual(log_conc,
                                             viability,
                                             pars = neighbours[i, ],
