@@ -28,14 +28,15 @@ geneDrugSensitivity <- function(x, type, batch, drugpheno, interaction.typexgene
 
   standardize <- match.arg(standardize)
 
-  colnames(drugpheno) <- paste("drugpheno", 1:ncol(drugpheno), sep=".")
+  colnames(drugpheno) <- paste("drugpheno", seq_len(ncol(drugpheno)), sep=".")
 
-  drugpheno <- data.frame(sapply(drugpheno, function(x) {
+  drugpheno <- data.frame(vapply(drugpheno, function(x) {
     if (!is.factor(x)) {
       x[is.infinite(x)] <- NA
     }
     return(list(x))
-  }, USE.NAMES=FALSE), check.names=FALSE)
+  }, USE.NAMES=FALSE), check.names=FALSE,
+  FUN.VALUE=list(1))
 
   ccix <- complete.cases(x, type, batch, drugpheno)
   nn <- sum(ccix)
@@ -43,7 +44,7 @@ geneDrugSensitivity <- function(x, type, batch, drugpheno, interaction.typexgene
   if(length(table(drugpheno)) > 2){
      if(ncol(drugpheno)>1){
       ##### FIX NAMES!!!
-      rest <- lapply(1:ncol(drugpheno), function(i){
+      rest <- lapply(seq_len(ncol(drugpheno)), function(i){
 
         est <- paste("estimate", i, sep=".")
         se <-  paste("se", i, sep=".")
@@ -89,15 +90,12 @@ geneDrugSensitivity <- function(x, type, batch, drugpheno, interaction.typexgene
     xx <- x[ccix]
   }
   if(ncol(drugpheno)>1){
-    ff0 <- paste("cbind(", paste(paste("drugpheno", 1:ncol(drugpheno), sep="."), collapse=","), ")", sep="")
+    ff0 <- paste("cbind(", paste(paste("drugpheno", seq_len(ncol(drugpheno)), sep="."), collapse=","), ")", sep="")
   } else {
     ff0 <- sprintf("drugpheno.1")
   }
 
-  # ff1 <- sprintf("%s + x", ff0)
-
   dd <- data.frame(drugpheno, "x"=xx)
-  # , "x"=xx, "type"=type[ccix], "batch"=batch[ccix])
 
   ## control for tissue type
   if(length(sort(unique(type))) > 1) {
@@ -107,31 +105,17 @@ geneDrugSensitivity <- function(x, type, batch, drugpheno, interaction.typexgene
   if(length(sort(unique(batch))) > 1) {
         dd <- cbind(dd, batch=batch[ccix])
   }
-  ## control for duration
-  # if(length(sort(unique(duration))) > 1){
-  #   ff0 <- sprintf("%s + duration", ff0)
-  #   ff <- sprintf("%s + duration", ff)
-  # }
 
-  # if(is.factor(drugpheno[,1])){
-
-  #   drugpheno <- drugpheno[,1]
-
-  # } else {
-
-  #   drugpheno <- as.matrix(drugpheno)
-
-  # }
-if(any(unlist(lapply(drugpheno,is.factor)))){
+  if(any(unlist(lapply(drugpheno,is.factor)))){
 
 rr0 <- tryCatch(try(glm(formula(drugpheno.1 ~ . - x), data=dd, model=FALSE, x=FALSE, y=FALSE, family="binomial")),
     warning=function(w) {
       if(verbose) {
         ww <- "Null model did not convrge"
-        print(ww)
+        message(ww)
         if("type" %in% colnames(dd)) {
           tt <- table(dd[,"type"])
-          print(tt)
+          message(tt)
         }
       }
     })
@@ -140,8 +124,8 @@ rr0 <- tryCatch(try(glm(formula(drugpheno.1 ~ . - x), data=dd, model=FALSE, x=FA
       if(verbose) {
         ww <- "Model did not converge"
         tt <- table(dd[,"drugpheno.1"])
-        print(ww)
-        print(tt)
+        message(ww)
+        message(tt)
       }
       return(ww)
     })
@@ -153,10 +137,10 @@ rr0 <- tryCatch(try(lm(formula(paste(ff0, "~ . -x", sep=" ")), data=dd)),
     warning=function(w) {
       if(verbose) {
         ww <- "Null model did not converge"
-        print(ww)
+        message(ww)
         if("type" %in% colnames(dd)) {
           tt <- table(dd[,"type"])
-          print(tt)
+          message(tt)
         }
       }
     })
@@ -165,8 +149,8 @@ rr0 <- tryCatch(try(lm(formula(paste(ff0, "~ . -x", sep=" ")), data=dd)),
       if(verbose) {
         ww <- "Model did not converge"
         tt <- table(dd[,"drugpheno.1"])
-        print(ww)
-        print(tt)
+        message(ww)
+        message(tt)
       }
       return(ww)
     })
@@ -174,8 +158,9 @@ rr0 <- tryCatch(try(lm(formula(paste(ff0, "~ . -x", sep=" ")), data=dd)),
 
 }
 
-
-  if (class(rr0) != "try-error" && class(rr1) != "try-error" & class(rr0) != "character" && class(rr1) != "character") {
+  ## FIXME:: Do we really want a vectorized and here?
+  if (!is(rr0, "try-error") && !is(rr1, "try-error") &
+      !is(rr0, "character") && !is(rr1, "character")) {
     rr <- summary(rr1)
 
     if(any(unlist(lapply(drugpheno,is.factor)))){
@@ -186,7 +171,7 @@ rr0 <- tryCatch(try(lm(formula(paste(ff0, "~ . -x", sep=" ")), data=dd)),
     } else {
       if(ncol(drugpheno)>1){
         rrc <- summary(stats::manova(rr1))
-        rest <- lapply(1:ncol(drugpheno), function(i) {
+        rest <- lapply(seq_len(ncol(drugpheno)), function(i) {
           est <- paste("estimate", i, sep=".")
           se <-  paste("se", i, sep=".")
           tstat <- paste("tstat", i, sep=".")
@@ -203,26 +188,7 @@ rr0 <- tryCatch(try(lm(formula(paste(ff0, "~ . -x", sep=" ")), data=dd)),
       }
     }
 
-
-#    rest <- c("estimate"=rr$coefficients["x", "Estimate"], "se"=rr$coefficients["x", "Std. Error"], "n"=nn, "tsat"=rr$coefficients["x", "t value"], "fstat"=rrc$F[2], "pvalue"=rrc$'Pr(>F)'[2])
-
-#   names(rest) <- c("estimate", "se", "n", "tstat", "fstat", "pvalue")
-
-## add tissue type/cell line statistics
-#     if(length(sort(unique(type))) > 1) {
-#       rr <- summary(rr0)
-#       ttype <- c("type.fstat"=rr$fstatistic["value"], "type.pvalue"=pf(q=rr$fstatistic["value"], df1=rr$fstatistic["numdf"], df2=rr$fstatistic["dendf"], lower.tail=FALSE))
-#       names(ttype) <- c("type.fstat", "type.pvalue")
-#     } else { ttype <- c("type.fstat"=NA, "type.pvalue"=NA) }
-#     rest <- c(rest, ttype)
-    ## add model
     if(model) { rest <- list("stats"=rest, "model"=rr1) }
   }
   return(rest)
-}
-
-
-
-
-
-## End
+}
\ No newline at end of file
