@@ -1,23 +1,29 @@
-#' Rank genes based on drug effect
-#'
-#' A helper function called from within `drugPerturbationSig`. This is intended
-#'   for developer use only; if you aren't debugging the package, this should
-#'   not be used.
-#'
-#' @param data: gene expression data matrix
-#' @param drug: single or vector of drug(s) of interest; if a vector of drugs is provided, they will be considered as being the same drug and will be jointly analyszed
-#' @param drug.id: drug used in each experiment
-#' @param drug.concentration: drug concentration used in each experiment
-#' @param type: cell or tissue type for each experiment
-#' @param xp: type of experiment (perturbation or control)
-#' @param batch: experiment batches
-#' @param duration: The duration of the experiment, in a consistent unit
-#' @param single.type: Should the statitsics be computed for each cell/tissue type separately?
-#' @param nthread: number of parallel threads (bound to the maximum number of cores available)
-#'
-#' @return [list] of \code{data.frame}s with the statistics for each gene, for each type
-#' @keywords internal
-#' @export
+# Rank genes based on drug effect
+#
+# A helper function called from within `drugPerturbationSig`. This is intended
+#   for developer use only; if you aren't debugging the package, this should
+#   not be used.
+#
+# @param data: gene expression data matrix
+# @param drug: single or vector of drug(s) of interest; if a vector of drugs is
+#    provided, they will be considered as being the same drug and will be
+#    jointly analyszed
+# @param drug.id: drug used in each experiment
+# @param drug.concentration: drug concentration used in each experiment
+# @param type: cell or tissue type for each experiment
+# @param xp: type of experiment (perturbation or control)
+# @param batch: experiment batches
+# @param duration: The duration of the experiment, in a consistent unit
+# @param single.type: Should the statitsics be computed for each cell/tissue
+#   type separately?
+# @param nthread: number of parallel threads (bound to the maximum number of
+#   cores available)
+#
+# @return [list] of \code{data.frame}s with the statistics for each gene, for
+#   each type
+#
+# @keywords internal
+# @export
 rankGeneDrugPerturbation <-
   function(data, drug, drug.id, drug.concentration, type, xp, batch, duration,
            single.type=FALSE, nthread=1, verbose=FALSE) {
@@ -25,11 +31,9 @@ rankGeneDrugPerturbation <-
     if (nthread != 1) {
       availcore <- parallel::detectCores()
       if (missing(nthread) || nthread < 1 || nthread > availcore) {
-        # print(paste("available cores",availcore,"allocated"))
         nthread <- availcore
       }
       else{
-        # print(paste("all",nthread,"cores have been allocated"))
       }
     }
 
@@ -75,8 +79,8 @@ rankGeneDrugPerturbation <-
         if (verbose) {
           cat(sprintf("type %s: batch %i/%i -> %i vs %i\n", utype[bb], bb, length(ubatch), length(xpix), length(ctrlix)))
         }
-        ## transformation of drug concentrations values
-        conc <- drug.concentration * 10^6
+        ## transformation of drug concentrations values - decision made to keep in µm
+        conc <- drug.concentration # / 10^6
         inpumat <- rbind(inpumat, data.frame("treated"=c(rep(1, length(xpix)), rep(0, length(ctrlix))), "type"=c(type[xpix], type[ctrlix]), "batch"=paste("batch", c(batch[xpix], batch[ctrlix]), sep=""), "concentration"=c(conc[xpix], conc[ctrlix]), "duration"= c(duration[xpix], duration[ctrlix])))
       }
     }
@@ -100,7 +104,7 @@ rankGeneDrugPerturbation <-
       names(ltype)[-1] <- utype
     }
 
-    for(ll in 1:length(ltype)) {
+    for(ll in seq_along(ltype)) {
 
       ## select the type of cell line/tissue of interest
       inpumat2 <- inpumat[!is.na(inpumat[ , "type"]) & is.element(inpumat[ , "type"], ltype[[ll]]), , drop=FALSE]
@@ -116,8 +120,9 @@ rankGeneDrugPerturbation <-
         if(nthread > 1) {
           ## parallel threads
           splitix <- parallel::splitIndices(nx=ncol(data), ncl=nthread)
-          splitix <- splitix[sapply(splitix, length) > 0]
-          mcres <- parallel::mclapply(splitix, function(x, data, inpumat) {
+          ##TODO:: Can we reimplement this without using length?
+          splitix <- splitix[vapply(splitix, length, FUN.VALUE=numeric(1)) > 0]
+          mcres <- BiocParallel::bplapply(splitix, function(x, data, inpumat) {
             res <- t(apply(data[rownames(inpumat), x, drop=FALSE], 2, ToxicoGx::geneDrugPerturbation, concentration=inpumat[ , "concentration"], type=inpumat[ , "type"], batch=inpumat[ , "batch"], duration=inpumat[,"duration"]))
             return(res)
           }, data=data, inpumat=inpumat2)
