@@ -70,8 +70,6 @@ summarizeSensitivityProfiles <- function(tSet,
   summary.stat <- match.arg(summary.stat)
 
   pp <- ToxicoGx::sensitivityInfo(tSet)
-  ## TODO:: Determine what this supposed to do?
-  #ppRows <- which(pp$cellid %in% cell_lines & pp$drugid %in% drugs & pp$duration_h %in% duration) ### NEEDED to deal with duplicated rownames!!!!!!!
 
   if (sensitivity.measure != "max.conc") {
     #if the sensitivity.measure specified is not "max.conc"
@@ -96,20 +94,7 @@ summarizeSensitivityProfiles <- function(tSet,
   rownames(result) <- drugs
   colnames(result) <- cell_lines
 
-
-  ## TODO:: Finish progress bar
-  # if(verbose){
-
-  #   message(sprintf("Summarizing %s sensitivity data for:\t%s", sensitivity.measure, tSet@annotation$name))
-  #   total <- length(drugs)*length(cell_lines)
-  #   # create progress bar
-  #   pb <- utils::txtProgressBar(min=0, max=total, style=3)
-  #   i <- 1
-
-
-  # }
-
-  pp_dd <- cbind(pp[,c("cellid", "drugid","duration_h")], "sensitivity.measure" = dd[, sensitivity.measure])
+  pp_dd <- cbind(pp[,c("sampleid", "treatmentid","duration_h")], "sensitivity.measure" = dd[, sensitivity.measure])
 
   summary.function <- function(x) {
     if (all(is.na(x))) {
@@ -138,17 +123,14 @@ summarizeSensitivityProfiles <- function(tSet,
   }
 
   pp_dd <- pp_dd[
-    pp_dd[,"cellid"] %in% cell_lines &
-    pp_dd[,"drugid"] %in% drugs &
+    pp_dd[,"sampleid"] %in% cell_lines &
+    pp_dd[,"treatmentid"] %in% drugs &
     pp_dd[,"duration_h"] %in% duration,
 
     ]
 
-  tt <- reshape2::acast(pp_dd, drugid~cellid, fun.aggregate = summary.function,
+  tt <- reshape2::acast(pp_dd, treatmentid ~ sampleid, fun.aggregate = summary.function,
                         value.var = "sensitivity.measure")
-  # tt <- tt[drugs, cell_lines]
-
-
 
   result[rownames(tt), colnames(tt)] <- tt
 
